@@ -9,6 +9,10 @@ from stopots_bot.utils import cls
 
 
 def init_chromedriver() -> webdriver:
+  """
+  Inicializa o chromedriver.
+  :return: webdriver chrome
+  """
   options = webdriver.ChromeOptions()
   options.add_experimental_option('excludeSwitches', ['enable-logging'])
   chrome_args = ['--log-level=3', '--silent', '--disable-extensions', '--disable-popup-blocking',
@@ -21,6 +25,10 @@ def init_chromedriver() -> webdriver:
 
 
 def init_geckodriver() -> webdriver:
+  """
+  Inicializa o geckodriver.
+  :return: webdriver geckodriver
+  """
   firefox_capabilities = DesiredCapabilities.FIREFOX
   firefox_capabilities['marionette'] = True
   geckodriver = webdriver.Firefox(executable_path=GeckoDriverManager().install(),
@@ -30,6 +38,11 @@ def init_geckodriver() -> webdriver:
 
 
 def init_webdriver(name: str = 'chrome') -> webdriver:
+  """
+  Inicializa o webdriver (padrão = 'chrome')
+  :param name: nome do webdriver
+  :return: webdriver
+  """
   try:
     return init_chromedriver() if name == 'chrome' else init_geckodriver()
   except Exception as e:
